##############################################################################
# The MIT License (MIT)
#
# Copyright (c) 2016-2019 Hajime Nakagami<nakagami@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
##############################################################################

DB2_SQLTYPE_DATE = 384
DB2_SQLTYPE_NDATE = 385
DB2_SQLTYPE_TIME = 388
DB2_SQLTYPE_NTIME = 389
DB2_SQLTYPE_TIMESTAMP = 392
DB2_SQLTYPE_NTIMESTAMP = 393
DB2_SQLTYPE_DATALINK = 396
DB2_SQLTYPE_NDATALINK = 397

DB2_SQLTYPE_BLOB = 404
DB2_SQLTYPE_NBLOB = 405
DB2_SQLTYPE_CLOB = 408
DB2_SQLTYPE_NCLOB = 409
DB2_SQLTYPE_DBCLOB = 412
DB2_SQLTYPE_NDBCLOB = 413

DB2_SQLTYPE_VARCHAR = 448
DB2_SQLTYPE_NVARCHAR = 449
DB2_SQLTYPE_CHAR = 452
DB2_SQLTYPE_NCHAR = 453
DB2_SQLTYPE_LONG = 456
DB2_SQLTYPE_NLONG = 457
DB2_SQLTYPE_CSTR = 460
DB2_SQLTYPE_NCSTR = 461
DB2_SQLTYPE_VARGRAPH = 464
DB2_SQLTYPE_NVARGRAPH = 465
DB2_SQLTYPE_GRAPHIC = 468
DB2_SQLTYPE_NGRAPHIC = 469
DB2_SQLTYPE_LONGRAPH = 472
DB2_SQLTYPE_NLONGRAPH = 473

DB2_SQLTYPE_LSTR = 476
DB2_SQLTYPE_NLSTR = 477

DB2_SQLTYPE_FLOAT = 480
DB2_SQLTYPE_NFLOAT = 481
DB2_SQLTYPE_DECIMAL = 484
DB2_SQLTYPE_NDECIMAL = 485
DB2_SQLTYPE_ZONED = 488
DB2_SQLTYPE_NZONED = 489

DB2_SQLTYPE_BIGINT = 492
DB2_SQLTYPE_NBIGINT = 493
DB2_SQLTYPE_INTEGER = 496
DB2_SQLTYPE_NINTEGER = 497
DB2_SQLTYPE_SMALL = 500
DB2_SQLTYPE_NSMALL = 501

DB2_SQLTYPE_NUMERIC = 504
DB2_SQLTYPE_NNUMERIC = 505

DB2_SQLTYPE_ROWID = 904
DB2_SQLTYPE_NROWID = 905
DB2_SQLTYPE_BLOB_LOCATOR = 960
DB2_SQLTYPE_NBLOB_LOCATOR = 961
DB2_SQLTYPE_CLOB_LOCATOR = 964
DB2_SQLTYPE_NCLOB_LOCATOR = 965
DB2_SQLTYPE_DBCLOB_LOCATOR = 968
DB2_SQLTYPE_NDBCLOB_LOCATOR = 969

DB2_SQLTYPE_BOOLEAN = 2436
DB2_SQLTYPE_NBOOLEAN = 2437

DB2_SQLTYPE_FAKE_UDT = 2000
DB2_SQLTYPE_FAKE_NUDT = 2001


SECMEC_DCESEC = 1
SECMEC_USRIDPWD = 3
SECMEC_USRIDONL = 4
SECMEC_USRIDNWPWD = 5
SECMEC_USRSBSPWD = 6
SECMEC_USRENCPWD = 7
SECMEC_USRSSBPWD = 8
SECMEC_EUSRIDPWD = 9
SECMEC_EUSRIDNWPWD = 10
